@@ -15,7 +15,7 @@
 #define BUS_NAME "com.nokia.csd.Call"
 #define BUS_PATH "/com/nokia/csd/call"
 #define BUS_PATH_1 "/com/nokia/csd/call/1"
-#define BUS_PATH_2 "/com/nokia/csd/call"
+#define BUS_PATH_2 "/com/nokia/csd/call/2"
 #define INSTANCE_INTERFACE "com.nokia.csd.Call.Instance"
 
 #define DEFAULT_WHITELIST "/home/user/MyDocs/whitelist.txt"
